@echo OFF
rem  * *******************************************************************
rem  *               CBLALTE3.CMD - a Windows Command File               *
rem  *         This program is provided by SimoTime Technologies         *
rem  *           (C) Copyright 1987-2019 All Rights Reserved             *
rem  *             Web Site URL:   http://www.simotime.com               *
rem  *                   e-mail:   helpdesk@simotime.com                 *
rem  * *******************************************************************
rem  *
rem  * Text    - COBOL with Primary and Alternate Index Access
rem  * Author  - SimoTime Technologies
rem  * Date    - November 11, 2003
rem  * Version - 05.07.06
rem  *
rem  * This set of programs illustrate the use a COBOL program to access
rem  * a VSAM, KSDS and produce a report in customer-number sequence or
rem  * telephone-number sequence.
rem  * The customer-number is the primary key. The telephone-number is
rem  * the alternate index key.
rem  *
rem  * When running with Net Express the IBMCOMP an NOTRUNC directives
rem  * will be required to maintain compatability with the mainframe
rem  * format and field sizes for binary fields.
rem  *
rem  * This technique provides for the use of a single COBOL source
rem  * program that will run on z/OS, Windows or Unix.
rem  *
rem  * This set of programs will run on a Personal Computer with Windows
rem  * and Micro Focus Net Express.
rem  * ********************************************************************
rem  * Step 1 of 4, Set the global environment variables...
rem  *
     call ..\Env1BASE %CmdName%
     if "%SYSLOG%" == "" set syslog=c:\SimoLIBR\LOGS\SimoTime.LOG
     set CmdName=CblAltE3
rem  *
     call SimoNOTE "*******************************************************%CmdName%"
     call SimoNOTE "Starting CmdName %CmdName%"
     set ALTKSD=%BaseLib1%\DATA\Wrk1\ALTKSD.DAT
rem  * ********************************************************************
rem  * Step 2 of 4, Report by Telephone number sequence
rem  *
     set REPORT03=%BaseLib1%\DATA\Wrk1\ALTRPTP1.DAT
     if exist %REPORT03% erase %REPORT03%
rem  *
     run SimoEXEC EXEC CBLALTC3 PIX0
     if not "%errorlevel%" == "0" set JobStatus=0020
     if not "%JobStatus%" == "0000" goto :EojNOK
     if exist %REPORT03% (
        call SimoNOTE "* %CmdName% The Following was created in Sequence by Prime Index,"
        call SimoNOTE "* %CmdName% %REPORT03%")
rem  * ********************************************************************
rem  * Step 3 of 4,  Report by Telephone number sequence
rem  *
     set REPORT03=%BaseLib1%\DATA\Wrk1\ALTRPTP2.DAT
     if exist %REPORT03% erase %REPORT03%
rem  *
     run SimoEXEC EXEC CBLALTC3 AIX1
     if not "%errorlevel%" == "0" set JobStatus=0030
     if not "%JobStatus%" == "0000" goto :EojNOK
     if exist %REPORT03% (
        call SimoNOTE "* %CmdName% The Following was created in Sequence by Alternate Index,"
        call SimoNOTE "* %CmdName% %REPORT03%")
rem  * ********************************************************************
rem  * Step 4 of 4, End-of-Job processing
rem  *
:EojAOK
     call SimoNOTE "Finished CmdName %CmdName%, Job Status is %JobStatus%"
     goto :End
:EojNOK
     call SimoNOTE "ABENDING CmdName %CmdName%, Job Status is %JobStatus%"
     echo %DATE% - %TIME% Starting User ABEND Processing...>>%SYSLOG%
     set >>%SYSLOG%
     echo %DATE% - %TIME% Complete User ABEND Processing...>>%SYSLOG%
     goto :End
:End
     call SimoNOTE "Conclude SysOut is %SYSOUT%"
     if not "%1" == "nopause" pause
     exit /B %JobStatus%
