@echo OFF
rem  * *******************************************************************
rem  *               CBLALTE9.CMD - a Windows Command File               *
rem  *         This program is provided by SimoTime Technologies         *
rem  *           (C) Copyright 1987-2019 All Rights Reserved             *
rem  *             Web Site URL:   http://www.simotime.com               *
rem  *                   e-mail:   helpdesk@simotime.com                 *
rem  * *******************************************************************
rem  *
rem  * Text    - Sequentially write new records to an indexed file.
rem  * Author  - SimoTime Technologies
rem  * Date    - November 11, 2003
rem  * Version - 04.03.12
rem  *
rem  * This set of programs illustrate the use a COBOL program to read
rem  * a sequential file and write new records to a VSAM, KSDS or
rem  * indexed file.
rem  * The customer-number is the primary key.
rem  *
rem  * When running with Net Express the IBMCOMP an NOTRUNC directives
rem  * will be required to maintain compatability with the mainframe
rem  * format and field sizes for binary fields.
rem  *
rem  * This technique provides for the use of a single COBOL source
rem  * program that will run on OS/390, Windows or Unix.
rem  *
rem  * This set of programs will run on a Personal Computer with Windows
rem  * and Micro Focus Net Express.
rem  * ********************************************************************
rem  * Step 1 of 4, Set the global environment variables...
rem  *
     call ..\Env1BASE %CmdName%
     if "%SYSLOG%" == "" set syslog=c:\SimoLIBR\LOGS\SimoTime.LOG
     set CmdName=CblAltE9
rem  *
     call SimoNOTE "*******************************************************%CmdName%"
     call SimoNOTE "Starting CmdName %CmdName%"
     set ALTQSMD2=%BaseLib1%\DATA\Wrk1\ALTQSMD2.DAT
     set ALTKSD=%BaseLib1%\DATA\Wrk1\ALTKSD.DAT
     if exist %ALTKSD% set JobStatus=0010
     if not "%JobStatus%" == "0000" goto :EojNOK
rem  * ********************************************************************
rem  * Step 2 of 4, Load the data into the indexed file...
rem  *
     run CBLALTC9
     if errorlevel = 1 set JobStatus=0020
     if not "%JobStatus%" == "0000" goto :EojNOK
rem  * ********************************************************************
rem  * Step 3 of 4, Build the alternate index...
rem  *
rem  *  /e    Reports illegal duplicate keys and continues processing
rem  *  /i    Displays information about the files being processed
rem  *  /x:n  Specifies the order in which data is written when
rem  *        reorganizing an indexed file
rem  *        n=0 Primary Index
rem  *        n=1 1st Alternate Index, etc...
rem  *
     rebuild %BaseLib1%\DATA\Wrk1\ALTKSD.DAT /ka:69+12d /e /x:0 /i
     if errorlevel = 1 set JobStatus=0030
     if not "%JobStatus%" == "0000" goto :EojNOK
rem  * ********************************************************************
rem  * Step 4 of 4, End-of-Job...
rem  *
:EojAOK
     call SimoNOTE " ..."
     call SimoNOTE "Finished CmdName %CmdName%, Job Status is %JobStatus%"
     goto :End
:EojNOK
     call SimoNOTE "ABENDING CmdName %CmdName%, Job Status is %JobStatus%"
     echo %DATE% - %TIME% Starting User ABEND Processing...>>%SYSLOG%
     set >>%SYSLOG%
     echo %DATE% - %TIME% Complete User ABEND Processing...>>%SYSLOG%
     goto :End
:End
     call SimoNOTE "Conclude SysOut is %SYSOUT%"
     if not "%1" == "nopause" pause
     exit /B %JobStatus%

