//CBLALTJ0 JOB SIMOTIME,CLASS=1,MSGCLASS=0,NOTIFY=CSIP1
//* *******************************************************************
//*       CBLALTJ0.JCL - a JCL Member for Batch Job Processing        *
//*       This JCL Member is provided by SimoTime Technologies        *
//*           (C) Copyright 1987-2019 All Rights Reserved             *
//*             Web Site URL:   http://www.simotime.com               *
//*                   e-mail:   helpdesk@simotime.com                 *
//* *******************************************************************
//* Text   - JCL using the IDCAMS Utility to delete a VSAM Cluster.
//*          Subsequent job steps will delete the sequential files
//*          that are created by the suite of jobs for the ALTERNATE
//*          INDEX suite of example programs.
//* Author - SimoTime Technologies
//* Date   - January 1, 1998
//*-------------------------------------------------------------------
//* The following example is more than what is usually required to
//* delete a VSAM Data Set. However, the purpose is to illustrate the
//* functions of the IDCAMS utility.
//*  PURGE: A VSAM Data Set may be date-protected. The DEFINE Cluster
//*         has the option of specifying a retention date. If this
//*         retention date has not expired then the PURGE option will
//*         be required in order to delete the data set.
//*         The default is NOPURGE.
//*  ERASE: The standard operation by the VSAM DELETE is to delete
//*         the catalog entry of the cluster and mark the space used
//*         by the cluster as reclaimable. The data contents of the
//*         cluster is no longer generally available but it is still
//*         present until the area is reused. This introduces a
//*         potential problem or security exposure for sensitive data.
//*         The information could be retrieved using some special
//*         class of DUMP/RESTORE utilities that are often used by
//*         data center staff. The ERASE function will write over the
//*         data area used by the cluster and the original data is
//*         destroyed. The default is NOERASE.
//*  SET:   The MAXCC = 0 will reset a non-zero return code to ZERO.
//*         This ensures a ZERO return code if this job is executed
//*         and the data set does not exist.
//*
//*********************************************************************
//* Step 1 of 4, Delete a previously created VSAM KSDS Cluster...
//*
//KDEL0512 EXEC PGM=IDCAMS
//SYSPRINT DD  SYSOUT=*
//SYSIN    DD  *
 DELETE    SIMOTIME.DATA.ALTKSD         -
           FILE(ALTKSD)                 -
           PURGE                        -
           ERASE                        -
           CLUSTER
 SET       MAXCC = 0
/*
//*
//* *******************************************************************
//* Step 2 of 4, Delete any previously created work files...
//*
//CLEANUP1 EXEC PGM=IEFBR14
//ALTQSMD1 DD  DSN=SIMOTIME.DATA.ALTQSMD1,DISP=(MOD,DELETE,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=80,BLKSIZE=800,DSORG=PS)
//ALTQSMD2 DD  DSN=SIMOTIME.DATA.ALTQSMD2,DISP=(MOD,DELETE,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=80,BLKSIZE=8000,DSORG=PS)
//ALTQSMD3 DD  DSN=SIMOTIME.DATA.ALTQSMD3,DISP=(MOD,DELETE,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=80,BLKSIZE=8000,DSORG=PS)
//*
//* *******************************************************************
//* Step 3 of 4, Delete previously created report files.
//*
//DELRPTDN EXEC PGM=IEFBR14
//REPORT01 DD  DSN=SIMOTIME.DATA.ALTRPTD1,DISP=(MOD,DELETE,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=133,DSORG=PS)
//REPORT02 DD  DSN=SIMOTIME.DATA.ALTRPTD2,DISP=(MOD,DELETE,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=133,DSORG=PS)
//*
//* *******************************************************************
//* Step 4 of 4, Delete previously created report files.
//*
//DELRPTPN EXEC PGM=IEFBR14
//REPORTP1 DD  DSN=SIMOTIME.DATA.ALTRPTP1,DISP=(MOD,DELETE,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=133,DSORG=PS)
//REPORTP2 DD  DSN=SIMOTIME.DATA.ALTRPTP2,DISP=(MOD,DELETE,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=133,DSORG=PS)
//*
