//CBLALTJ9 JOB SIMOTIME,CLASS=1,MSGCLASS=0,NOTIFY=CSIP1
//* *******************************************************************
//*       CBLALTJ9.JCL - a JCL Member for Batch Job Processing        *
//*       This JCL Member is provided by SimoTime Technologies        *
//*           (C) Copyright 1987-2019 All Rights Reserved             *
//*             Web Site URL:   http://www.simotime.com               *
//*                   e-mail:   helpdesk@simotime.com                 *
//* *******************************************************************
//*
//* Text   - Create a VSAM, KSDS with an alternate index.
//* Author - SimoTime Technologies
//* Date   - January 24, 1991
//*
//* This job will use IDCAMS to create a VSAM, KSDS data set with an
//* alternate index. The primary key is twelve characters starting at
//* the first position in the record. The Alternate key is twelve
//* characters starting at position 69 of the record.
//* The record length is 512 characters.
//*
//* The purpose of this procedure is to create and load a new VSAM
//* Key-Sequenced-Data-Set (KSDS) with a primary key of a customer
//* number and an alternate index of the telephone number. The
//* procedure does an ordered load (i.e. sequential processing) for
//* speed in populating the file. Therefore, the records to be added
//* must be added in sequence.
//*
//* This set of programs will run on a mainframe under MVS or on a
//* Personal Computer with Windows and Micro Focus Mainframe Express.
//*
//* *******************************************************************
//* Step 1 of 5, Create a VSAM Cluster for a Key-Sequenced-Data-Set.
//*
//KSDCRTS1 EXEC PGM=IDCAMS
//SYSPRINT DD   SYSOUT=*
//SYSIN    DD   *
 DEFINE    CLUSTER  (NAME (SIMOTIME.DATA.ALTKSD)              -
                     TRACKS (45 15)                           -
                     RECORDSIZE (512 512)                     -
                     FREESPACE (10 15)                        -
                     KEYS (12 0)                              -
                     INDEXED)                                 -
           DATA     (NAME (SIMOTIME.DATA.ALTKSD.DAT)          -
                     CISZ (8192))                             -
           INDEX    (NAME (SIMOTIME.DATA.ALTKSD.IDX))
/*
//*
//* *******************************************************************
//* Step 2 of 5, Read Sequential File, populate (or Write records to)
//*              the VSAM Key-Sequenced-Data-Set (KSDS).
//*
//ADDNEWS1 EXEC PGM=CBLALTC9
//STEPLIB  DD  DSN=MFI01.SIMOPROD.LOADLIB1,DISP=SHR
//ALTQSMD2 DD  DSN=SIMOTIME.DATA.ALTQSMD2,DISP=SHR
//ALTKSD   DD  DSN=SIMOTIME.DATA.ALTKSD,DISP=SHR
//SYSOUT   DD  SYSOUT=*
//*
//* *******************************************************************
//* Step 3 of 5, Define an Alternate Index based on telephone number.
//*
//DEFALTIX EXEC PGM=IDCAMS
//SYSPRINT DD   SYSOUT=*
//SYSIN    DD   *
 DEFINE    AIX      (NAME (SIMOTIME.DATA.ALTKSD1)             -
                     RELATE (SIMOTIME.DATA.ALTKSD)            -
                     RECORDSIZE (512 512)                     -
                     TRACKS (10 5)                            -
                     KEYS (12 68)                             -
                     UPGRADE)
/*
//*
//* *******************************************************************
//* Step 4 of 5, Define an path for the Alternate index.
//*
//DEFPATH  EXEC PGM=IDCAMS
//SYSPRINT DD   SYSOUT=*
//SYSIN    DD   *
 DEFINE    PATH     (NAME (SIMOTIME.DATA.ALTKSD.PATH)         -
                     PATHENTRY (SIMOTIME.DATA.ALTKSD1)        -
                     UPDATE                                   -
                    )
/*
//*
//* *******************************************************************
//* Step 5 of 5, Build the Alternate Index.
//*
//BLDINDEX EXEC PGM=IDCAMS
//SYSPRINT DD   SYSOUT=*
//BASEDD   DD   DSN=SIMOTIME.DATA.ALTKSD,DISP=OLD
//AIXDD    DD   DSN=SIMOTIME.DATA.ALTKSD1,DISP=OLD
//IDCUT1   DD   UNIT=SYSDA,SPACE=(CYL,55)
//IDCUT2   DD   UNIT=SYSDA,SPACE=(CYL,55)
//SYSIN    DD   *
 BLDINDEX  INFILE (BASEDD)                    -
           OUTFILE (AIXDD)
/*
//*
